@@ -128,13 +128,14 @@ OC.L10N.register(
     "Contact vCard as QR code" : "联系人名片作为二维码",
     "Pick an address book" : "选择一个地址簿",
     "Select address book" : "选择地址簿",
+    "Go to talk conversation" : "前往对话",
+    "View profile" : "查看个人资料",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
     "Address book" : "地址簿",
     "Add contact to Birthday Calendar" : "添加联系人到生日日历",
     "Exclude contact from Birthday Calendar" : "从生日日历中排除联系人",
     "{title} at {organization}" : "{organization} 的 {title}",
-    "New contact" : "新建联系人",
     "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
     "The contact does not exist on the server anymore." : "服务器上不再存在此联系人。",
     "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器获取联系人，请检查您的网络连接。",
@@ -184,6 +185,7 @@ OC.L10N.register(
     "none" : "无",
     "Select option" : "选择选项",
     "Add property of this type" : "为此类型添加属性",
+    "New contact" : "新建联系人",
     "Unable to create the contact." : "未能成功创建联系人。",
     "Contact not found" : "未找到联系人",
     "Group {group} not found" : "未找到小组 {group} ",
@@ -208,6 +210,7 @@ OC.L10N.register(
     "Not grouped" : "未分组",
     "Recently contacted" : "最近联系",
     "Organization chart" : "组织图",
+    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "小圈圈是您可以自行建立并与他们分享资料的一群人。其可以由 Nextcloud 实例的其他账号或账号群组所组成，但也可以由您通讯录中的联络人组成，甚至可以通过输入邮件地址来添加外部人员。",
     "Circle" : "圈子",
     "User" : "用户",
     "Group" : "小组",
